@@ -16,7 +16,7 @@ Example usage:
 u'Cabin Fever'
 """
 __author__ = "dbr/Ben"
-__version__ = "0.7"
+__version__ = "1.0"
 
 import os
 import sys
@@ -41,6 +41,7 @@ class ShowContainer(dict):
     """
     pass
 
+
 class Show(dict):
     """Holds a dict of seasons, and show data.
     """
@@ -53,6 +54,7 @@ class Show(dict):
             self.data.get(u'seriesname', 'instance'),
             len(self)
         )
+
     def __getitem__(self, key):
         if key in self:
             # Key is an episode, return it
@@ -76,28 +78,30 @@ class Show(dict):
         Search all episodes in show. Can search all data, or a specific key (for
         example, episodename)
 
-        Always returns an array (can be empty). First index is first
-        found episode, and so on.
+        Always returns an array (can be empty). First index contains the first
+        match, and so on.
 
         Each array index is an Episode() instance, so doing
         search_results[0]['episodename'] will retrieve the episode name of the
         first match.
 
-        Search terms are converted to lower case unicode strings.
+        Search terms are converted to lower case (unicode) strings.
 
-        Examples
+        # Examples
+        
         These examples assume t is an instance of Tvdb():
+        
         >>> t = Tvdb()
         >>>
 
-        Search for all episodes of Scrubs episodes
-        with a bit of data containing "my first day":
+        To search for all episodes of Scrubs with a bit of data
+        containing "my first day":
 
         >>> t['Scrubs'].search("my first day")
         [<Episode 01x01 - My First Day>]
         >>>
 
-        Search for "My Name Is Earl" named "Faked His Own Death":
+        Search for "My Name Is Earl" episode named "Faked His Own Death":
 
         >>> t['My Name Is Earl'].search('Faked His Own Death', key = 'episodename')
         [<Episode 01x04 - Faked His Own Death>]
@@ -109,7 +113,7 @@ class Show(dict):
         [<Episode 01x02 - My Mentor>, <Episode 03x15 - My Tormented Mentor>]
         >>>
 
-        Using search results
+        # Using search results
 
         >>> results = t['Scrubs'].search("my first")
         >>> print results[0]['episodename']
@@ -128,11 +132,13 @@ class Show(dict):
         #end for cur_season
         return results
 
+
 class Season(dict):
     def __repr__(self):
         return "<Season instance (containing %s episodes)>" % (
             len(self.keys())
         )
+
     def __getitem__(self, episode_number):
         if episode_number not in self:
             raise tvdb_episodenotfound("Could not find episode %s" % (repr(episode_number)))
@@ -140,15 +146,15 @@ class Season(dict):
             return dict.__getitem__(self, episode_number)
 
     def search(self, term = None, key = None):
-        """Search a all episodes in season, returns a list of matching Episode
+        """Search all episodes in season, returns a list of matching Episode
         instances.
 
         >>> t = Tvdb()
-        >>> t['scrubs'][1].search('first day')
+        >>> t['scrubs'][1].search('first')
         [<Episode 01x01 - My First Day>]
         >>>
 
-        See Episode.search documentation for further information on search
+        See Show.search documentation for further information on search
         """
         results = []
         for ep in self.values():
@@ -159,6 +165,7 @@ class Season(dict):
                 )
         return results
 
+
 class Episode(dict):
     def __repr__(self):
         seasno = int(self.get(u'seasonnumber', 0))
@@ -168,15 +175,20 @@ class Episode(dict):
             return "<Episode %02dx%02d - %s>" % (seasno, epno, epname)
         else:
             return "<Episode %02dx%02d>" % (seasno, epno)
+
     def __getitem__(self, key):
         try:
             return dict.__getitem__(self, key)
         except KeyError:
             raise tvdb_attributenotfound("Cannot find attribute %s" % (repr(key)))
+
     def search(self, term = None, key = None):
-        """Search episodes data for term, if it matches, return the Episode.
-        The key parameter can be used to limit the search to a specific element.
-        for example, episodename
+        """Search episode data for term, if it matches, return the Episode (self).
+        The key parameter can be used to limit the search to a specific element,
+        for example, episodename.
+        
+        This primarily for use use by Show.search and Season.search. See
+        Show.search for further information on search
 
         Simple example:
 
@@ -206,9 +218,16 @@ class Episode(dict):
             #end if cur_value.find()
         #end for cur_key, cur_value
 
+
+class Actors(list):
+    """Holds all Actor instances for a show
+    """
+    pass
+
+
 class Actor(dict):
     """Represents a single actor. Should contain..
-    
+
     id,
     image,
     name,
@@ -218,10 +237,6 @@ class Actor(dict):
     def __repr__(self):
         return "<Actor \"%s\">" % (self.get("name"))
 
-class Actors(list):
-    """Holds all Actor instances for a show
-    """
-    pass
 
 class Tvdb:
     """Create easy-to-use interface to name of season/episode name
@@ -229,7 +244,8 @@ class Tvdb:
     >>> t['Scrubs'][1][24]['episodename']
     u'My Last Day'
     """
-    def __init__(self, interactive = False,
+    def __init__(self,
+                interactive = False,
                 select_first = False,
                 debug = False,
                 cache = True,
@@ -237,10 +253,10 @@ class Tvdb:
                 actors = False,
                 custom_ui = None,
                 language = None,
-                search_all_languages = False):
+                search_all_languages = False,
+                apikey = None):
         """interactive (True/False):
-            When True, uses built-in console UI is used to select
-            the correct show.
+            When True, uses built-in console UI is used to select the correct show.
             When False, the first search result is used.
 
         select_first (True/False):
@@ -262,36 +278,46 @@ class Tvdb:
 
             >>> Tvdb(banners=True)['scrubs']['_banners'].keys()
             ['fanart', 'poster', 'series', 'season']
-        
+
         actors (True/False):
             Retrieves a list of the actors for a show. These are accessed
             via the _actors key of a Show(), for example:
-        
+
             >>> t = Tvdb(actors=True)
             >>> t['scrubs']['_actors'][0]['name']
             u'Zach Braff'
 
         custom_ui (tvdb_ui.BaseUI subclass):
-            A callable subclass of tvdb_ui.BaseUI (overrides interactive)
-        
+            A callable subclass of tvdb_ui.BaseUI (overrides interactive option)
+
         language (2 character language abbreviation):
             The language of the returned data. Is also the language search
             uses. Default is "en" (English). For full list, run..
-            
+
             >>> Tvdb().config['valid_languages'] #doctest: +ELLIPSIS
             ['da', 'fi', 'nl', ...]
-        
+
         search_all_languages (True/False):
             By default, Tvdb will only search in the language specified using
             the language option. When this is True, it will search for the
             show in and language
+        
+        apikey (str/unicode):
+            Override the default thetvdb.com API key. By default it will use
+            tvdb_api's own key (fine for small scripts), but you can use your
+            own key if desired - this is recommended if you are embedding
+            tvdb_api in a larger application)
+            See http://thetvdb.com/?tab=apiregister to get your own key
         """
         self.shows = ShowContainer() # Holds all Show classes
         self.corrections = {} # Holds show-name to show_id mapping
 
         self.config = {}
 
-        self.config['apikey'] = "0629B785CE550C8D" # thetvdb.com API key
+        if apikey is not None:
+            self.config['apikey'] = apikey
+        else:
+            self.config['apikey'] = "0629B785CE550C8D" # tvdb_api's API key
 
         self.config['debug_enabled'] = debug # show debugging messages
 
@@ -300,7 +326,7 @@ class Tvdb:
         self.config['interactive'] = interactive # prompt for correct series?
 
         self.config['select_first'] = select_first
-        
+
         self.config['search_all_languages'] = search_all_languages
 
         if cache is True:
@@ -379,9 +405,13 @@ class Tvdb:
     #end initLogger
 
     def _getTempDir(self):
+        """Returns the [system temp dir]/tvdb_api
+        """
         return os.path.join(tempfile.gettempdir(), "tvdb_api")
 
     def _getetsrc(self, url):
+        """Loads a URL sing caching, returns an ElementTree of the source
+        """
         try:
             self.log.debug("Retrieving ElementTree source for URL %s" % (url))
             resp = self.urlopener.open(url)
@@ -398,7 +428,6 @@ class Tvdb:
         return et
     #end _getetsrc
 
-
     def _setItem(self, sid, seas, ep, attrib, value):
         """Creates a new episode, creating Show(), Season() and
         Episode()s as required. Called by _getShowData to populute
@@ -434,8 +463,8 @@ class Tvdb:
         """Cleans up strings returned by TheTVDB.com
 
         Issues corrected:
-        - Returns &amp; instead of &, since &s in filenames
-        are bad, replace &amp; with "&"
+        - Replaces &amp; with &
+        - Trailing whitespace
         """
         data = data.replace(u"&amp;", u"&")
         data = data.strip()
@@ -444,8 +473,9 @@ class Tvdb:
 
     def _getSeries(self, series):
         """This searches TheTVDB.com for the series name,
-        and either interactively selects the correct show,
-        or returns the first result.
+        If a custom_ui UI is configured, it uses this to select the correct
+        series. If not, and interactive == True, ConsoleUI is used, if not
+        BaseUI is used to select the first result.
         """
         series = urllib.quote(series.encode("utf-8"))
         self.log.debug("Searching for show %s" % series)
@@ -496,7 +526,7 @@ class Tvdb:
         Any key starting with an underscore has been processed (not the raw
         data from the XML)
 
-        This interface will be improved!
+        This interface will be improved in future versions.
         """
         self.log.debug('Getting season banners for %s' % (sid))
         bannersEt = self._getetsrc( self.config['url_seriesBanner'] % (sid) )
@@ -538,7 +568,7 @@ class Tvdb:
     def _parseActors(self, sid):
         """Parsers actors XML, from
         http://www.thetvdb.com/api/[APIKEY]/series/[SERIES ID]/actors.xml
-        
+
         Actors are retrieved using t['show name]['_actors'], for example:
 
         >>> t = Tvdb(actors = True)
@@ -561,7 +591,7 @@ class Tvdb:
         """
         self.log.debug("Getting actors for %s" % (sid))
         actorsEt = self._getetsrc(self.config['url_actorsInfo'] % (sid))
-        
+
         cur_actors = Actors()
         for curActorItem in actorsEt.findall("Actor"):
             curActor = Actor()
@@ -651,6 +681,12 @@ class Tvdb:
         """Handles tvdb_instance['seriesname'] calls.
         The dict index should be the show id
         """
+        if isinstance(key, (int, long)):
+            # Item is integer, treat as show id
+            if key not in self.shows:
+                self._getShowData(key)
+            return self.shows[key]
+        
         key = key.lower() # make key lower case
         sid = self._nameToSid(key)
         self.log.debug('Got series id %s' % (sid))
